@@ -146,7 +146,11 @@ RPB_FUNCTION_VOID_2(METHOD(serialize_to_file), Rcpp::XPtr<GPB::Message> message,
 RPB_FUNCTION_1(Rcpp::RawVector, METHOD(get_payload), Rcpp::XPtr<GPB::Message> message) {
 
     /* create a raw vector of the appropriate size */
-    int size = message->ByteSize();
+#if GOOGLE_PROTOBUF_VERSION < 3006001
+    R_xlen_t size = message->ByteSize();
+#else
+    R_xlen_t size = message->ByteSizeLong();
+#endif
     Rcpp::RawVector payload(size);
 
     /* fill the array */
@@ -250,7 +254,11 @@ RPB_FUNCTION_1(S4_Descriptor, METHOD(descriptor), Rcpp::XPtr<GPB::Message> messa
 }
 
 RPB_XP_METHOD_0(METHOD(as_character), GPB::Message, DebugString)
-RPB_XP_METHOD_0(METHOD(bytesize), GPB::Message, ByteSize)
+#if GOOGLE_PROTOBUF_VERSION < 3006001
+  RPB_XP_METHOD_0(METHOD(bytesize), GPB::Message, ByteSize)
+#else
+  RPB_XP_METHOD_0(METHOD(bytesize), GPB::Message, ByteSizeLong)
+#endif
 
 RPB_FUNCTION_2(int, METHOD(field_size), Rcpp::XPtr<GPB::Message> message, SEXP field) {
     const GPB::FieldDescriptor* field_desc = getFieldDescriptor(message, field);
@@ -427,6 +435,33 @@ RPB_FUNCTION_1(Rcpp::CharacterVector, METHOD(fieldNames), Rcpp::XPtr<GPB::Messag
     return (res);
 }
 
+/**
+ * Returns the JSON representation of the message.
+ *
+ * @param xp external pointer to a Message
+ *
+ * @return JSON representation of the message as a single element R character vector (STRSXP)
+ */
+RPB_FUNCTION_1(Rcpp::CharacterVector, METHOD(as_json), Rcpp::XPtr<GPB::Message> message) {
+#ifdef PROTOBUF_JSON_UTIL
+    GPB::util::JsonPrintOptions opts;
+    opts.add_whitespace = true;
+
+    std::string buf;
+    GPB::util::Status status = GPB::util::MessageToJsonString(*message, &buf, opts);
+    if (!status.ok()) {
+        Rcpp::stop(status.ToString().c_str());
+    }
+    Rcpp::CharacterVector res(1);
+    res[0] = buf;
+    return (res);
+#else
+    Rcpp::stop(
+        "The protobuf library you are using is too old for using JSON utility functions, "
+        "please upgrade to version 3 or above.");
+#endif
+}
+
 bool identical_messages_(const GPB::Message* m1, const GPB::Message* m2, double tol) {
     const GPB::Descriptor* d1 = m1->GetDescriptor();
     const GPB::Descriptor* d2 = m2->GetDescriptor();
